@@ -1,33 +1,29 @@
-
-#'@title 
-#'Creates a time series plot of the thermocline and top and 
-#'bottom of the metalimnion
-#'
-#'@description
-#' A line based plot of calculated depths of the thermocline, and 
-#' top and bottom of the metalimnion from a temperature profile time series.
-#'
-#'@param wtr Data frame of water temperature loaded with \code{\link{load.ts}}.
-#'@param ... Additional paramters supplied to \code{\link{ts.meta.depths}} and \code{\link{ts.thermo.depth}}
-#'
-#'@author Jennifer Brentrup, Taylor Leach, Luke Winslow
-#'
-#'@seealso \code{\link{load.ts}} and \code{\link{wtr.lineseries}}
-#'
-#'@keywords hplot 
-#'
-#'@examples
-#'
-#'wtr.path <- system.file('extdata', 'Sparkling.wtr', package="rLakeAnalyzer")
-#'
-#'#Load data for example lake, Sparkilng Lake, Wisconsin.
-#'wtr = load.ts(wtr.path)
-#'
-#'\dontrun{
-#'wtr.plot.temp(wtr)
-#'}
-#'
-#'@export
+#' @title Creates a time series plot of the thermocline and top and bottom of the
+#' metalimnion
+#' 
+#' @description A line based plot of calculated depths of the thermocline, and top and
+#' bottom of the metalimnion from a temperature profile time series.
+#' 
+#' 
+#' @param wtr Data frame of water temperature loaded with
+#' \code{\link{load.ts}}.
+#' @param ... Additional paramters supplied to \code{\link{ts.meta.depths}} and
+#' \code{\link{ts.thermo.depth}}
+#' @seealso \code{\link{load.ts}} and \code{\link{wtr.lineseries}}
+#' @keywords hplot
+#' @examples
+#' 
+#' 
+#' wtr.path <- system.file('extdata', 'Sparkling.wtr', package="rLakeAnalyzer")
+#' 
+#' #Load data for example lake, Sparkilng Lake, Wisconsin.
+#' wtr = load.ts(wtr.path)
+#' 
+#' \dontrun{
+#' wtr.plot.temp(wtr)
+#' }
+#' 
+#' @export
 wtr.plot.temp = function(wtr, ...){
   
   depths = get.offsets(wtr[,-1])
@@ -35,7 +31,7 @@ wtr.plot.temp = function(wtr, ...){
   md = ts.meta.depths(wtr, ...)
   
   df = list(wtr,td,md) ##Create list of data frame to join
-  wtr.all = join_all(df, by="datetime") ##Joins thermodepths, metadepths with temp data
+  wtr.all = plyr::join_all(df, by="datetime") ##Joins thermodepths, metadepths with temp data
   
   nn = ncol(wtr) # number of columns in data set
   starttime = min(wtr[,1]) #earliest date
@@ -84,7 +80,7 @@ wtr.plot.temp = function(wtr, ...){
     xxlab <- " "
   }
   
-  plot(wtr.all[,nn+1]~wtr.all[,1],
+  graphics::plot(wtr.all[,nn+1]~wtr.all[,1],
        type='l',
        col="black",
        ylab="Depth (m)",
@@ -94,19 +90,19 @@ wtr.plot.temp = function(wtr, ...){
        xlim=c(starttime,endtime),
        axes=F
   )
-  lines(wtr.all[,nn+2]~wtr.all[,1], type='l',col="orangered")
-  lines(wtr.all[,nn+3]~wtr.all[,1], type='l',col="navy")
+  graphics::lines(wtr.all[,nn+2]~wtr.all[,1], type='l',col="orangered")
+  graphics::lines(wtr.all[,nn+3]~wtr.all[,1], type='l',col="navy")
   
   # x axis
-  axis(side = 3, labels=format(datestoshow, ttformat), at = datestoshow, pos = c(min(depths)), tck = -0.03)
-  segments(c(starttime),c(min(depths)),c(endtime),c(min(depths)), col = "black", lty = 1)
+  graphics::axis(side = 3, labels=format(datestoshow, ttformat), at = datestoshow, pos = c(min(depths)), tck = -0.03)
+  graphics::segments(c(starttime),c(min(depths)),c(endtime),c(min(depths)), col = "black", lty = 1)
   
   # y axis
-  axis (side  = 2, pos = c(starttime), at = NULL, las = 1)
-  segments(c(starttime),c(min(depths)),c(starttime),c(max(depths)), col = "black")
+  graphics::axis (side  = 2, pos = c(starttime), at = NULL, las = 1)
+  graphics::segments(c(starttime),c(min(depths)),c(starttime),c(max(depths)), col = "black")
   
   # generate and place legend
-  legend( "bottom"
+  graphics::legend( "bottom"
           , col = c("orangered", "black","navy")
           , lty = 1, lwd = 3, bty = "n"
           , legend = c("Metalimnion Top (m)","Thermocline Depth (m)", "Metalimnion Bottom (m)")
